Returns a connection to the INBO Watina data warehouse. The function can only be used from within the INBO network.
Details
Don't forget to disconnect at the end of your R-script using
dbDisconnect!
Examples
if (FALSE) { # \dontrun{
watina <- connect_watina()
# Do your stuff.
# Disconnect:
dbDisconnect(watina)
} # }